===========
policy.yaml
===========

Use the ``policy.yaml`` file to define additional access controls that will be
applied to Searchlight:

.. literalinclude:: ../_static/searchlight.policy.yaml.sample
